pub enum SecretProtectedKeyEnvelopeError {
WrongSecret,
Parsing(String),
Kdf,
KeyMissing,
KeyStore,
InvalidNamespace,
}Expand description
Errors that can occur when sealing or unsealing a key with the SecretProtectedKeyEnvelope.
Variants
WrongSecret
The secret provided is incorrect or the envelope was tampered with
Parsing(String)
The envelope could not be parsed correctly, or the KDF parameters are invalid
Kdf
The KDF failed to derive a key, possibly due to invalid parameters
KeyMissing
There is no key for the provided key id in the key store
KeyStore
The key store could not be written to, for example due to being read-only
InvalidNamespace
The namespace provided in the envelope does not match any known namespaces, or is invalid