struct HkdfSettings {
alg: Algorithm,
salt: [u8; 32],
}Expand description
Raw HKDF settings. The salt is a fixed size, randomly generated value. Unlike a memory-hard KDF, HKDF has no difficulty parameters to tune, since the input secret is assumed to be high-entropy.
Fields
alg: Algorithmsalt: [u8; 32]Implementations
Sourceimpl HkdfSettings
impl HkdfSettings